@@ -1,9 +1,9 @@
 package Data::CSel;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-09'; # DATE
+our $DATE = '2021-07-01'; # DATE
 our $DIST = 'Data-CSel'; # DIST
-our $VERSION = '0.123'; # VERSION
+our $VERSION = '0.124'; # VERSION
 
 use 5.020000;
 use strict;
@@ -618,7 +618,7 @@ sub _simpsel {
             } elsif ($pc eq 'nth-last-of-type') {
                 @res = grep { Code::Includable::Tree::NodeMethods::is_nth_last_child_of_type($_, $f->{args}[0]) } @res;
             } elsif ($pc eq 'root') {
-                @res = grep { !$_->parent } @res;
+                @res = grep { Code::Includable::Tree::NodeMethods::is_root($_) } @res;
             } elsif ($pc eq 'empty') {
                 @res = grep { my @c = Code::Includable::Tree::NodeMethods::_children_as_list($_); !@c } @res;
             } elsif ($pc eq 'has') {
@@ -633,6 +633,8 @@ sub _simpsel {
                 my %matches_refaddrs;
                 for (@matches) { $matches_refaddrs{refaddr($_)}++ }
                 @res = grep { !$matches_refaddrs{refaddr($_)} } @res;
+            } elsif ($pc eq 'parent') {
+                @res = _uniq_objects(map { Code::Includable::Tree::NodeMethods::retrieve_parent($_) } @res);
             } else {
                 die "Unsupported pseudo-class '$pc'";
             }
@@ -734,7 +736,7 @@ Data::CSel - Select tree node objects using CSS Selector-like syntax
 
 =head1 VERSION
 
-This document describes version 0.123 of Data::CSel (from Perl distribution Data-CSel), released on 2020-04-09.
+This document describes version 0.124 of Data::CSel (from Perl distribution Data-CSel), released on 2021-07-01.
 
 =head1 SYNOPSIS
 
@@ -1253,10 +1255,16 @@ type.
 
 Select only root node(s).
 
+=item * C<:parent>
+
+Select the node's parent.
+
 =item * C<:empty>
 
 Select only leaf node(s).
 
+See also C<:has>.
+
 =item * C<:not(S)>
 
 Select all objects not matching selector C<S>. C<S> can be a string or an
@@ -1281,6 +1289,8 @@ Example:
 
 will select all objects that have a descendant of type C<T>.
 
+See also: C<:parent>.
+
 =back
 
 =head2 Differences with CSS selector
@@ -1527,7 +1537,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
